@@ -1,4 +1,5 @@
 ### R code from vignette source 'CNVassoc_vignette.Rnw'
+### Encoding: ISO8859-1
 
 ###################################################
 ### code chunk number 1: CNVassoc_vignette.Rnw:62-63
@@ -302,110 +303,7 @@ cumsum(table(cut(pvalsBH[, 2], c(-Inf, 1e-5, 1e-4, 1e-3, 1e-2, 0.05))))
 
 
 ###################################################
-### code chunk number 47: CNVassoc_vignette.Rnw:784-785
-###################################################
-data(A112)
-
-
-###################################################
-### code chunk number 48: CNVassoc_vignette.Rnw:788-789
-###################################################
-head(A112)
-
-
-###################################################
-### code chunk number 49: CNVassoc_vignette.Rnw:792-793
-###################################################
-head(A112)
-
-
-###################################################
-### code chunk number 50: CNVassoc_vignette.Rnw:807-808
-###################################################
-library(CNVtools)
-
-
-###################################################
-### code chunk number 51: CNVassoc_vignette.Rnw:817-819
-###################################################
-raw.signal <- as.matrix(A112[, -c(1, 2)])
-dimnames(raw.signal)[[1]] <- A112$subject
-
-
-###################################################
-### code chunk number 52: CNVassoc_vignette.Rnw:823-824
-###################################################
-pca.signal <- apply.pca(raw.signal)
-
-
-###################################################
-### code chunk number 53: CNVassoc_vignette.Rnw:829-834
-###################################################
-ncomp <- 3
-batches <- factor(A112$cohort)
-sample <- factor(A112$subject)
-fit.pca <- CNVtest.binary(signal = pca.signal, sample = sample, 
-batch = batches, ncomp = ncomp, n.H0 = 3, n.H1 = 0, model.var = "~ strata(cn)")
-
-
-###################################################
-### code chunk number 54: CNVassoc_vignette.Rnw:838-842
-###################################################
-pca.posterior <- as.matrix((fit.pca$posterior.H0)[, paste("P", 
-seq(1:ncomp), sep = "")])
-dimnames(pca.posterior)[[1]] <- (fit.pca$posterior.H0)$subject
-ldf.signal <- apply.ldf(raw.signal, pca.posterior)
-
-
-###################################################
-### code chunk number 55: CNVassoc_vignette.Rnw:855-857
-###################################################
-CNV <- cnv(ldf.signal, batches = batches, num.class = 3, mix = "mclust")
-CNV
-
-
-###################################################
-### code chunk number 56: CNVassoc_vignette.Rnw:871-872
-###################################################
-plot(CNV)
-
-
-###################################################
-### code chunk number 57: CNVassoc_vignette.Rnw:890-893
-###################################################
-trait <- ifelse(A112$cohort == "58C", 0, 1)
-fit <- CNVassoc(trait ~ CNV, model = "add")
-CNVtest(fit,"LRT")
-
-
-###################################################
-### code chunk number 58: CNVassoc_vignette.Rnw:896-901
-###################################################
-# by default CNVtest.binary assumes: model.var = "~ strata(batch, cn)", model.disease = "~ cn" (trend CNV effect, and different vars per batch).
-fit.cnvtools <- CNVtest.binary(signal = ldf.signal, sample = sample, 
-batch = batches, disease.status = trait, ncomp = ncomp, n.H0 = 3, n.H1 = 1,
-model.var = "~cn")
-chi.cnvtools <- -2*(fit.cnvtools$model.H0$lnL - fit.cnvtools$model.H1$lnL)
-
-
-###################################################
-### code chunk number 59: CNVassoc_vignette.Rnw:908-910
-###################################################
-fit <- CNVassoc(trait ~ CNV)
-CNVtest(fit, "LRT")
-
-
-###################################################
-### code chunk number 60: CNVassoc_vignette.Rnw:913-917
-###################################################
-fit.cnvtools <- CNVtest.binary(signal = ldf.signal, sample = sample,
-batch = batches, disease.status = trait,ncomp = 3, n.H0 = 3, n.H1 = 1,
-model.disease = "~as.factor(cn)")
-chi.cnvtools  <- -2*(fit.cnvtools$model.H0$lnL - fit.cnvtools$model.H1$lnL)
-
-
-###################################################
-### code chunk number 61: CNVassoc_vignette.Rnw:1018-1021
+### code chunk number 47: CNVassoc_vignette.Rnw:793-796
 ###################################################
 data(SNPTEST)
 dim(cases)
@@ -413,31 +311,31 @@ dim(controls)
 
 
 ###################################################
-### code chunk number 62: CNVassoc_vignette.Rnw:1025-1026
+### code chunk number 48: CNVassoc_vignette.Rnw:800-801
 ###################################################
 cases[1:10,1:11]
 
 
 ###################################################
-### code chunk number 63: CNVassoc_vignette.Rnw:1029-1030
+### code chunk number 49: CNVassoc_vignette.Rnw:804-805
 ###################################################
 cases[1:10,1:11]
 
 
 ###################################################
-### code chunk number 64: CNVassoc_vignette.Rnw:1034-1035
+### code chunk number 50: CNVassoc_vignette.Rnw:809-810
 ###################################################
 controls[1:10,1:11]
 
 
 ###################################################
-### code chunk number 65: CNVassoc_vignette.Rnw:1038-1039
+### code chunk number 51: CNVassoc_vignette.Rnw:813-814
 ###################################################
 controls[1:10,1:11]
 
 
 ###################################################
-### code chunk number 66: CNVassoc_vignette.Rnw:1067-1075
+### code chunk number 52: CNVassoc_vignette.Rnw:842-850
 ###################################################
 nSNP <- nrow(cases)
 probs <- lapply(1:nSNP, function(i) {
@@ -450,33 +348,33 @@ ncol = 3, byrow = TRUE)
 
 
 ###################################################
-### code chunk number 67: CNVassoc_vignette.Rnw:1084-1085
+### code chunk number 53: CNVassoc_vignette.Rnw:859-860
 ###################################################
 casecon <- rep(1:0, c(500, 500))
 
 
 ###################################################
-### code chunk number 68: CNVassoc_vignette.Rnw:1090-1092
+### code chunk number 54: CNVassoc_vignette.Rnw:865-867
 ###################################################
 pvals <- multiCNVassoc(probs, formula = "casecon~CNV", model = "add",
 num.copies = 0:2, cnv.tol = 0.001)
 
 
 ###################################################
-### code chunk number 69: CNVassoc_vignette.Rnw:1096-1098
+### code chunk number 55: CNVassoc_vignette.Rnw:871-873
 ###################################################
 pvalsBH <- getPvalBH(pvals)
 head(pvalsBH)
 
 
 ###################################################
-### code chunk number 70: CNVassoc_vignette.Rnw:1102-1103
+### code chunk number 56: CNVassoc_vignette.Rnw:877-878
 ###################################################
 table(cut(pvalsBH[, 2], c(-Inf, 1e-3, 1e-2, 0.05, 0.1, Inf)))
 
 
 ###################################################
-### code chunk number 71: CNVassoc_vignette.Rnw:1140-1147
+### code chunk number 57: CNVassoc_vignette.Rnw:915-922
 ###################################################
 set.seed(123456)
 rr <- 1.7
@@ -488,21 +386,21 @@ head(dsim)
 
 
 ###################################################
-### code chunk number 72: CNVassoc_vignette.Rnw:1159-1161
+### code chunk number 58: CNVassoc_vignette.Rnw:934-936
 ###################################################
 CNV <- cnv(dsim$surrog, mix = "mclust")
 CNV
 
 
 ###################################################
-### code chunk number 73: CNVassoc_vignette.Rnw:1166-1168
+### code chunk number 59: CNVassoc_vignette.Rnw:941-943
 ###################################################
 fit <- CNVassoc(resp ~ CNV, data = dsim, family = "poisson", model = "add")
 coef(summary(fit))
 
 
 ###################################################
-### code chunk number 74: CNVassoc_vignette.Rnw:1175-1180
+### code chunk number 60: CNVassoc_vignette.Rnw:950-955
 ###################################################
 fit.gold <- glm(resp ~ cnv, data = dsim, family = "poisson")
 table.gold <- c(exp(c(coef(fit.gold)[2], confint(fit.gold)[2,])), 
@@ -512,7 +410,7 @@ table.gold
 
 
 ###################################################
-### code chunk number 75: CNVassoc_vignette.Rnw:1190-1195
+### code chunk number 61: CNVassoc_vignette.Rnw:965-970
 ###################################################
 fit.naive <- glm(resp ~ CNV, data = dsim, family = "poisson")
 table.naive <- c(exp(c(coef(fit.naive)[2], confint(fit.naive)[2,])), 
@@ -522,7 +420,7 @@ table.naive
 
 
 ###################################################
-### code chunk number 76: CNVassoc_vignette.Rnw:1199-1205
+### code chunk number 62: CNVassoc_vignette.Rnw:974-980
 ###################################################
 taula <- rbind(
 table.gold[1:3],
@@ -533,7 +431,7 @@ xtable(taula,"Comparison of RR estimated by the gold standard model, a latent cl
 
 
 ###################################################
-### code chunk number 77: CNVassoc_vignette.Rnw:1241-1255
+### code chunk number 63: CNVassoc_vignette.Rnw:1016-1030
 ###################################################
 set.seed(123456)
 n <- 5000
@@ -552,14 +450,14 @@ head(dsim)
 
 
 ###################################################
-### code chunk number 78: CNVassoc_vignette.Rnw:1269-1271
+### code chunk number 64: CNVassoc_vignette.Rnw:1044-1046
 ###################################################
 CNV<-cnv(dsim$surrog,mix="mclust")
 CNV
 
 
 ###################################################
-### code chunk number 79: CNVassoc_vignette.Rnw:1278-1280
+### code chunk number 65: CNVassoc_vignette.Rnw:1053-1055
 ###################################################
 fit<-CNVassoc(Surv(resp,cens)~CNV, data=dsim, family="weibull", model="add")
 coef(summary(fit))
